8. Professional Services — Py4J

Py4J - A Bridge between Python and Java

### Navigation

- index
- modules |
- next |
- previous |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »

# 8. Professional Services

We regularly receive requests on GitHub or on our private email to implement difficult or niche features or to provide commercial support.

The company that the creator of Py4J works for, Resulto, has agreed to provide professional services for Py4J. This means that you can hire Resulto if you want:

- a feature to be implemented quickly
- a special license that comes with commercial support
- custom integration with your code

The creator of Py4J, Barthélémy, will not stop developing Py4J for free, quite the opposite, but large or niche features that require uninterrupted hours of R&D/thinking do not always fit in the limited personal time of the Py4J contributors.

In the end, professional services should greatly benefit Py4J users because new features will be introduced in the code base and bugs will inevitably be fixed along the way.

If you are interested in professional services for Py4J, please get in touch with us at py4j@resulto.ca.

## 8.1. FAQ

### 8.1.1. Will you stop supporting Py4J or implementing features for free?

No. Barthélémy will continue with exactly the same schedule: intense bursts of open source activity followed by answering bug reports and merging pull requests only. If you want a complex feature to be implemented and Barthélémy does not have the time on his personal time, you are welcome to implement it and make a pull request.

### 8.1.2. If I hire Resulto to implement a feature, how does the copyrights and licensing work?

Unless the feature integrates with a proprietary part of your system, we prefer to make the work open source following Py4J’s implicit contributor agreement.

### 8.1.3. Who is Resulto?

Resulto is a small software development company that started in May 2014. Their main product is a personalized marketing/customer retention platform, LoyalAction. Resulto also offers professional services to build custom platforms and infrastructure. If you hire Resulto to work on Py4J, Barthelemy will likely lead the effort, but other developers may also participate.

As a bonus, Resulto is located in Canada, so their currency is extremely cheap these days :-D

### 8.1.4. Is Resulto the new owner of Py4J?

No, Resulto is just a company offering professional services related to Py4J.

### 8.1.5. How does professional services work?

Professional services can be provided in many ways: license, formal contract with NDA, or simple email exchange followed by an online payment.

Usually, you will contact Resulto with a description of your needs, then you will receive a proposition with a fixed rate and fixed amount of hours so you get no surprise on your side and you do not write a blank check.

If the feature requires some R&D and the outcome is uncertain, Resulto will likely suggest to do some investigation work first before committing to a fixed rate and fixed amount of hours.

### 8.1.6. How can I contact Resulto?

Just send us an email with a description of your requirements or your questions at py4j@resulto.ca

### Questions/Feedback?

- Try the FAQ -- It answers many questions.
- Search for information in the archives of the py4j-users mailing list, or post a question.
- If you notice errors with this documentation, open a ticket and let us know. Please, only open a ticket for feedback or improvements on the docs. To get help, use the links above!
- Request professional services to get a custom feature implemented quickly or to receive commercial support.

### Navigation

- index
- modules |
- next |
- previous |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »